@@ -29,27 +29,25 @@ function file_re($file, $pattern, $all = true) {
 }
 
 $ifdefs = array(
-	'PRIMARY_IP' => 'PHP_HTTP_CURL_VERSION(7,19,0)',
-	'APPCONNECT_TIME' => 'PHP_HTTP_CURL_VERSION(7,19,0)',
-	'CONDITION_UNMET' => 'PHP_HTTP_CURL_VERSION(7,19,4)',
-	'PRIMARY_PORT' => 'PHP_HTTP_CURL_VERSION(7,21,0)',
-	'LOCAL_PORT' => 'PHP_HTTP_CURL_VERSION(7,21,0)',
-	'LOCAL_IP' => 'PHP_HTTP_CURL_VERSION(7,21,0)',
-	'HTTP_VERSION' => 'PHP_HTTP_CURL_VERSION(7,50,0)',
-	'PROXY_SSL_VERIFYRESULT' => 'PHP_HTTP_CURL_VERSION(7,52,0)',
-	'PROTOCOL' => 'PHP_HTTP_CURL_VERSION(7,52,0)',
-	'SCHEME' => 'PHP_HTTP_CURL_VERSION(7,52,0)',
 	'RETRY_AFTER' => 'PHP_HTTP_CURL_VERSION(7,66,0)',
 	'EFFECTIVE_METHOD' => 'PHP_HTTP_CURL_VERSION(7,72,0)',
 	'PROXY_ERROR' => 'PHP_HTTP_CURL_VERSION(7,73,0)',
 	'REFERER' => 'PHP_HTTP_CURL_VERSION(7,76,0)',
 	'CAINFO' => 'PHP_HTTP_CURL_VERSION(7,84,0)',
 	'CAPATH' => 'PHP_HTTP_CURL_VERSION(7,84,0)',
+	'CONN_ID' => 'PHP_HTTP_CURL_VERSION(8,2,0)',
+	'XFER_ID' => 'PHP_HTTP_CURL_VERSION(8,2,0)',
+	'QUEUE_TIME_T' => 'PHP_HTTP_CURL_VERSION(8,6,0)',
+	'USED_PROXY' => 'PHP_HTTP_CURL_VERSION(8,7,0)',
+	'POSTTRANSFER_TIME_T' => 'PHP_HTTP_CURL_VERSION(8,10,0)',
+	'HTTPAUTH_USED' => 'PHP_HTTP_CURL_VERSION(8,12,0)',
+	'PROXYAUTH_USED' => 'PHP_HTTP_CURL_VERSION(8,12,0)',
 );
 $exclude = array(
 	'ACTIVESOCKET',
 	'CERTINFO',
 	'COOKIELIST',
+	'EARLYDATA_SENT_T',
 	'FTP_ENTRY_PATH',
 	'LASTSOCKET',
 	'PRIVATE',
